@@ -1,6 +1,6 @@
 # fields  is a package for analysis of spatial data written for
 # the R software environment .
-# Copyright (C) 2017
+# Copyright (C) 2018
 # University Corporation for Atmospheric Research (UCAR)
 # Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
@@ -28,7 +28,7 @@
         which <- 1
     }
     fitted.values <- predict(out)
-    std.residuals <- (out$residuals * sqrt(out$weights))/out$shat.GCV
+    std.residuals <- (out$residuals * sqrt(out$weights))/out$tauHat.GCV
     if (any(which == 1)) {
         temp <- summary(out)
         plot(fitted.values, out$y, ylab = "Y", xlab = " predicted values", 
