@@ -1,7 +1,23 @@
-# fields, Tools for spatial data
-# Copyright 2015, Institute for Mathematics Applied Geosciences
-# University Corporation for Atmospheric Research
-# Licensed under the GPL -- www.gpl.org/licenses/gpl.html
+# fields  is a package for analysis of spatial data written for
+# the R software environment .
+# Copyright (C) 2018
+# University Corporation for Atmospheric Research (UCAR)
+# Contact: Douglas Nychka, nychka@ucar.edu,
+# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with the R software environment if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# or see http://www.r-project.org/Licenses/GPL-2    
 "print.summary.Krig" <- function(x, ...) {
     digits <- x$digits
     c1 <- "Number of Observations:"
@@ -22,20 +38,20 @@
     c2 <- c(c2, format(round(x$enp, 1)))
     c1 <- c(c1, "Residual degrees of freedom:")
     c2 <- c(c2, format(round(x$num.observation - x$enp, 1)))
-    c1 <- c(c1, "MLE sigma ")
-    c2 <- c(c2, format(signif(x$shat.MLE, digits)))
-    c1 <- c(c1, "GCV sigma ")
-    c2 <- c(c2, format(signif(x$shat.GCV, digits)))
-    if (!is.na(x$shat.pure.error)) {
-        c1 <- c(c1, "Pure error sigma")
-        c2 <- c(c2, format(signif(x$shat.pure.error, digits)))
+    c1 <- c(c1, "MLE tau ")
+    c2 <- c(c2, format(signif(x$tauHat.MLE, digits)))
+    c1 <- c(c1, "GCV tau ")
+    c2 <- c(c2, format(signif(x$tauHat.GCV, digits)))
+    if (!is.na(x$tauHat.pure.error)) {
+        c1 <- c(c1, "Pure error tau")
+        c2 <- c(c2, format(signif(x$tauHat.pure.error, digits)))
     }
-    c1 <- c(c1, "MLE rho ")
-    c2 <- c(c2, format(signif(x$rhohat, digits)))
-    c1 <- c(c1, "Scale passed for covariance (rho)")
-    c2 <- c(c2, signif(x$rho, digits))
-    c1 <- c(c1, "Scale passed for nugget (sigma^2)")
-    c2 <- c(c2, signif(x$sigma2, digits))
+    c1 <- c(c1, "MLE sigma ")
+    c2 <- c(c2, format(signif(x$sigmahat, digits)))
+    c1 <- c(c1, "Scale passed for covariance (sigma)")
+    c2 <- c(c2, signif(x$sigma, digits))
+    c1 <- c(c1, "Scale passed for nugget (tau^2)")
+    c2 <- c(c2, signif(x$tau2, digits))
     c1 <- c(c1, "Smoothing parameter lambda")
     c2 <- c(c2, signif(x$lambda, digits))
     sum <- cbind(c1, c2)
