@@ -1,6 +1,6 @@
 # fields  is a package for analysis of spatial data written for
 # the R software environment .
-# Copyright (C) 2017
+# Copyright (C) 2018
 # University Corporation for Atmospheric Research (UCAR)
 # Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
@@ -19,18 +19,23 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # or see http://www.r-project.org/Licenses/GPL-2    
 "setup.image.smooth" <- function(nrow = 64, ncol = 64, 
-    dx = 1, dy = 1, kernel.function = double.exp, theta = 1, 
-    xwidth = nrow * dx, ywidth = ncol * dx, lambda = NULL, ...) {
+    dx = 1, dy = 1, kernel.function = double.exp, aRange = 1, 
+    xwidth = nrow * dx, ywidth = ncol * dx, lambda = NULL, theta=NULL,  ...) {
+# theta is depreciated    
+    if( !is.null(theta)){
+        aRange<- theta
+    }
+#    
     M2 <- round((nrow + xwidth/dx)/2)
     N2 <- round((ncol + ywidth/dy)/2)
     M <- 2 * M2
     N <- 2 * N2
     xi <- seq(-(M2 - 1), M2, 1) * dx
-    xi <- xi/theta
+    xi <- xi/aRange
     
     yi <- seq(-(N2 - 1), (N2), 1) * dy
-    yi <- yi/theta
-    dd <- sqrt((matrix(xi, M, N)^2 + matrix(yi, M, N, byrow = TRUE)^2))
+    yi <- yi/aRange
+    dd <- ((matrix(xi, M, N)^2 + matrix(yi, M, N, byrow = TRUE)^2))
     out <- matrix(kernel.function(dd, ...), nrow = M, ncol = N)
     out2 <- matrix(0, M, N)
     out2[M2, N2] <- 1
