@@ -21,7 +21,7 @@
 "surface.Krig" <- function(object, grid.list = NULL, 
     extrap = FALSE, graphics.reset = NULL, xlab = NULL, ylab = NULL, 
     main = NULL, zlab = NULL, zlim = NULL, levels = NULL, type = "C", 
-    nx = 80, ny = 80, ...) {
+    nx = 80, ny = 80, col=viridis(256), ...) {
     ## modified so that you can give main, and ylab as arguments
     ## in ... and have them passed correctly
     out.p <- predictSurface(object, grid.list = grid.list, extrap = extrap, 
@@ -37,7 +37,7 @@
     ##    else
     ##      out.p$main <- NULL
     plot.surface(out.p, type = type, graphics.reset = graphics.reset, 
-        levels = levels, zlim = zlim, ...)
+        levels = levels, zlim = zlim,col=col,  ...)
     invisible()
 }
 
@@ -45,8 +45,8 @@
     UseMethod("surface")
 }
 
-"surface.default" <- function(object, ...) {
-    plot.surface(object, ...)
+"surface.default" <- function(object, col=viridis(256), ...) {
+    plot.surface(object, col=col, ...)
 }
 
 "surface.mKrig" <- function(object, grid.list = NULL, 
@@ -72,7 +72,3 @@
     invisible()
 }
 
-#"surface.surface" <- function(object, ...) {
-#    #
-#    plot.surface(object, ...)
-#}
